.. _ref_readme:

##################
PyAdditive-Widgets
##################

.. readme_start

|pyansys| |python| |pypi| |GH-CI| |codecov| |MIT| |black|

.. |pyansys| image:: https://img.shields.io/badge/Py-Ansys-ffc107.svg?logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAABDklEQVQ4jWNgoDfg5mD8vE7q/3bpVyskbW0sMRUwofHD7Dh5OBkZGBgW7/3W2tZpa2tLQEOyOzeEsfumlK2tbVpaGj4N6jIs1lpsDAwMJ278sveMY2BgCA0NFRISwqkhyQ1q/Nyd3zg4OBgYGNjZ2ePi4rB5loGBhZnhxTLJ/9ulv26Q4uVk1NXV/f///////69du4Zdg78lx//t0v+3S88rFISInD59GqIH2esIJ8G9O2/XVwhjzpw5EAam1xkkBJn/bJX+v1365hxxuCAfH9+3b9/+////48cPuNehNsS7cDEzMTAwMMzb+Q2u4dOnT2vWrMHu9ZtzxP9vl/69RVpCkBlZ3N7enoDXBwEAAA+YYitOilMVAAAAAElFTkSuQmCC
   :target: https://docs.pyansys.com/
   :alt: PyAnsys

.. |python| image:: https://img.shields.io/pypi/pyversions/ansys-additive-widgets?logo=pypi
   :target: https://pypi.org/project/ansys-additive-widgets/
   :alt: Python

.. |pypi| image:: https://img.shields.io/pypi/v/ansys-additive-widgets.svg?logo=python&logoColor=white
   :target: https://pypi.org/project/ansys-additive-widgets
   :alt: PyPI

.. |codecov| image:: https://codecov.io/gh/ansys/pyadditive-widgets/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/ansys/pyadditive-widgets
   :alt: Codecov

.. |GH-CI| image:: https://github.com/ansys/pyadditive-widgets/actions/workflows/ci_cd.yml/badge.svg
   :target: https://github.com/ansys/pyadditive-widgets/actions/workflows/ci_cd.yml
   :alt: GH-CI

.. |MIT| image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://opensource.org/licenses/MIT
   :alt: MIT

.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg?style=flat
   :target: https://github.com/psf/black
   :alt: Black

Overview
========

PyAdditive-Widgets is a widget toolkit for `PyAdditive`_ simulations. It provides
methods for visualizing the results of parametric additive simulations. Some examples
include viewing the study as a table, viewing the single bead simulation results as
a heat map, and viewing the porosity relative density results as a contour plot.

Documentation and issues
========================

Documentation for the latest stable release of PyAdditive-Widgets is hosted
at `PyAdditive-Widgets documentation`_.

The documentation has these sections:

- `Getting started`_: Learn how to install PyAdditive-Widgets in user mode.
- `User guide`_: Learn how to start a session with the PyAdditive client and run simulations.
- `API reference`_: Understand how to use Python to interact programmatically with PyAdditive-Widgets.
- `Examples`_: Explore examples that show how to use PyAdditive-Widgets to visualize the results of
  parametric additive simulations.
- `Contribute <https://widgets.additive.docs.pyansys.com/version/stable/contributing.html>`_: Learn how to
  contribute to the PyAdditive-Widgets codebase or documentation.

In the upper right corner of the documentation's title bar, there is an option
for switching from viewing the documentation for the latest stable release
to viewing the documentation for the development version or previously
released versions.

On the `PyAdditive-Widgets Issues <https://github.com/ansys/pyadditive-widgets/issues>`_
page, you can create issues to report bugs and request new features. On the
`Discussions <https://discuss.ansys.com/>`_ page on the Ansys Developer portal,
you can post questions, share ideas, and get community feedback.

If you have general questions about the PyAnsys ecosystem, email
`pyansys.core@ansys.com <pyansys.core@ansys.com>`_. If your
question is specific to PyAdditive-Widgets, ask your
question in an issue as described in the previous paragraph.

License
-------

PyAdditive-Widgets is licensed under the `MIT License <https://github.com/ansys/pyadditive-widget/blob/main/LICENSE>`_.

PyAdditive-Widgets makes no commercial claim over Ansys whatsoever. This library adds a
toolkit interface for visualizing the results of `PyAdditive`_ simulations.

Using PyAdditive-Widgets requires the prerequisites and package dependencies indicated
in the `Getting started <https://widgets.additive.docs.pyansys.com/version/stable/getting_started/index.html>`_
section of the PyAdditive-Widgets documentation.

.. LINKS AND REFERENCES
.. _Ansys Additive: https://www.ansys.com/products/additive
.. _PyAdditive: https://additive.docs.pyansys.com/version/stable/index.html
.. _PyAdditive documentation: https://additive.docs.pyansys.com/version/stable/index.html
.. _PyAdditive Getting Started: https://additive.docs.pyansys.com/version/stable/getting_started/index.html
.. _PyAdditive-Widgets documentation: https://widgets.additive.docs.pyansys.com/version/stable/index.html
.. _Getting started: https://widgets.additive.docs.pyansys.com/version/stable/getting_started/index.html
.. _User guide: https://widgets.additive.docs.pyansys.com/version/stable/user_guide/index.html
.. _API reference: https://widgets.additive.docs.pyansys.com/version/stable/api/index.html
.. _Examples: https://widgets.additive.docs.pyansys.com/version/stable/examples/gallery_examples/index.html
